@@ -17,19 +17,24 @@ class GenerateAuthenticate(object):
         super(GenerateAuthenticate,self).__init__(secret_key=secretKey,cipher_text=cipher_text)
 
     @staticmethod
-    def generate_access_token(SECRET_KEY):
-        expire = datetime.utcnow() + timedelta(minutes=5)
-        to_encode = {"exp": expire, "sub": str(123), "uid": str(uuid.uuid4())}
+    def generate_access_token(SECRET_KEY, Plaintext):
+        expire = datetime.utcnow() + timedelta(minutes=1)
+        to_encode = {"exp": expire, "sub": str(Plaintext), "uid": str(uuid.uuid4())}
         token = jwt.encode(to_encode, SECRET_KEY, algorithm="HS256")
         return token
 
     @staticmethod
-    def check_access_token(Ciphertext,secretKey):
+    def check_access_token(Ciphertext, secretKey):
         try:
-            payload = jwt.decode(Ciphertext,secretKey,algorithms="HS256")
-            print(payload)
+            payload = jwt.decode(Ciphertext, secretKey, algorithms="HS256")
+            import sys
+            if isinstance(payload, unicode) or sys.version_info[0] < 3:
+                print str(payload).encode('utf-8').replace('u\'', '')
+            else:
+                print(payload)
+            return payload
 
         except ExpiredSignatureError:
-            print("token过期")
+            print(u"token过期")
         except JWTError:
-            print("token验证失败")
+            print(u"token验证失败")
\ No newline at end of file
